# fibonacci_calculators
Provide two different ways to calculate fibonacci

## install
```shell
pip install fibonacci_calculators
```

## use
```python
from fibonacci_calculators import fibonacci_dfs, fibonacci_dp
print(fibonacci_dfs(5))
print(fibonacci_dp(5))
```